/*
** Zabbix
** Copyright (C) 2001-2020 Zabbix SIA
**
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
**/


/**
 * Call SVG graph widget internal processes.
 *
 * @param {string} hook_name - trigger name.
 */
function zbx_svggraph_widget_trigger(hook_name) {
	var grid = Array.prototype.slice.call(arguments, -1),
		grid = grid.length ? grid[0] : null;

	switch (hook_name) {
		case 'onResizeEnd':
			jQuery('.dashbrd-grid-container').dashboardGrid('refreshWidget', grid.widget['uniqueid']);
			break;

		case 'onEditStart':
			jQuery('svg', grid.widget['content_body']).svggraph('disableSBox');
			break;
	}
}
